@@ -580,7 +580,7 @@ def create_default_migrator(silent: bool = False) -> DatabaseMigrator:
     )
     
     remote_config = RemoteConfig(
-        ssh_host="git@e3",
+        ssh_host="git@ecslz",
         temp_dir="/tmp/db_migration",
         database=remote_db
     )
