@@ -153,8 +153,8 @@ class ZiniaoBrowser:
         self.config = config
 
     def open_store(self, store_info: str, isWebDriverReadOnlyMode: int = 0,
-            isprivacy: int = 0, isHeadless: int = 0,
-            cookieTypeSave: int = 0, jsInfo: str = "") -> Dict[str, Any]:
+                   isprivacy: int = 0, isHeadless: int = 0,
+                   cookieTypeSave: int = 0, jsInfo: str = "") -> Dict[str, Any]:
         """打开店铺"""
         request_id = str(uuid.uuid4())
         data = {
@@ -272,7 +272,7 @@ class ZiniaoTaskManager:
         self.browser = browser
         self.config = config
 
-    def daily_cleanup_superbrowser(self, browser_id):
+    def daily_cleanup_superbrowser(self, browser_id, force=False):
         """
         每天删除一次SuperBrowser缓存文件夹
 
@@ -318,7 +318,7 @@ class ZiniaoTaskManager:
                 log(f"读取标志文件时出错: {e}")
                 # 如果读取出错，继续执行清理
 
-        if need_cleanup:
+        if need_cleanup or force:
             try:
                 # 删除目标文件夹
                 log(f"正在删除文件夹: {target_folder}")
@@ -340,10 +340,10 @@ class ZiniaoTaskManager:
         return True
 
     def run_single_store_task(self, browser_info: Dict[str, Any],
-            run_func: Callable, task_key: str,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None
-    ):
+                              run_func: Callable, task_key: str,
+                              just_store_username: Optional[List[str]] = None,
+                              is_skip_store: Optional[Callable] = None
+                              ):
         """运行单个店铺的任务"""
         store_id = browser_info.get('browserOauth')
         store_name = browser_info.get("browserName")
@@ -420,24 +420,25 @@ class ZiniaoTaskManager:
                     break
             except:
                 send_exception(f'第{retry_count}次运行失败，准备重新打开店铺: {store_username},{store_name},{store_id}')
+                self.daily_cleanup_superbrowser(browser_id, True)
                 if retry_count > 5:
                     break
 
     def run_all_stores_task(self, browser_list: List[Dict[str, Any]],
-            run_func: Callable, task_key: str,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None
-    ):
+                            run_func: Callable, task_key: str,
+                            just_store_username: Optional[List[str]] = None,
+                            is_skip_store: Optional[Callable] = None
+                            ):
         """循环运行所有店铺的任务"""
         for browser_info in browser_list:
             self.run_single_store_task(browser_info, run_func, task_key, just_store_username, is_skip_store)
 
     def run_with_thread_pool(self, browser_list: List[Dict[str, Any]],
-            max_threads: int = 3, run_func: Callable = None,
-            task_key: str = None,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None
-    ):
+                             max_threads: int = 3, run_func: Callable = None,
+                             task_key: str = None,
+                             just_store_username: Optional[List[str]] = None,
+                             is_skip_store: Optional[Callable] = None
+                             ):
         """使用线程池控制最大并发线程数运行任务"""
         with ThreadPoolExecutor(max_workers=max_threads) as executor:
             task = partial(self.run_single_store_task,
@@ -460,14 +461,14 @@ class ZiniaoRunner:
         self.task_manager = ZiniaoTaskManager(self.browser, config)
 
     def execute(self, run_prepare: Optional[Callable] = None,
-            run: Optional[Callable] = None,
-            run_summary: Optional[Callable] = None,
-            run_notify: Optional[Callable] = None,
-            task_key: Optional[str] = None,
-            just_store_username: Optional[List[str]] = None,
-            is_skip_store: Optional[Callable] = None,
-            platform_name: Optional[str] = "SHEIN-全球",
-    ):
+                run: Optional[Callable] = None,
+                run_summary: Optional[Callable] = None,
+                run_notify: Optional[Callable] = None,
+                task_key: Optional[str] = None,
+                just_store_username: Optional[List[str]] = None,
+                is_skip_store: Optional[Callable] = None,
+                platform_name: Optional[str] = "SHEIN-全球",
+                ):
         """主执行入口"""
         # 前置执行 if run_prepare:
         run_prepare()
@@ -488,7 +489,7 @@ class ZiniaoRunner:
             raise RuntimeError("店铺列表为空")
 
         # 多线程并发执行任务
-        max_threads = 1 if (hostname().lower() == 'krrpa') else 3
+        max_threads = 3 if (hostname().lower() == 'krrpa' or hostname().lower() == 'jyrpa') else 3
         log(f'当前启用线程数: {max_threads}')
         self.task_manager.run_with_thread_pool(browser_list, max_threads, run, task_key, just_store_username, is_skip_store)
 
